[{"locale":"es"},{"category":"Lu","mappings":{"default":{"default":"sans-serif cursiva mayúscula A"}},"key":"1D608"},{"category":"Lu","mappings":{"default":{"default":"sans-serif cursiva mayúscula B"}},"key":"1D609"},{"category":"Lu","mappings":{"default":{"default":"sans-serif cursiva mayúscula C"}},"key":"1D60A"},{"category":"Lu","mappings":{"default":{"default":"sans-serif cursiva mayúscula D"}},"key":"1D60B"},{"category":"Lu","mappings":{"default":{"default":"sans-serif cursiva mayúscula E"}},"key":"1D60C"},{"category":"Lu","mappings":{"default":{"default":"sans-serif cursiva mayúscula F"}},"key":"1D60D"},{"category":"Lu","mappings":{"default":{"default":"sans-serif cursiva mayúscula G"}},"key":"1D60E"},{"category":"Lu","mappings":{"default":{"default":"sans-serif cursiva mayúscula H"}},"key":"1D60F"},{"category":"Lu","mappings":{"default":{"default":"sans-serif cursiva mayúscula I"}},"key":"1D610"},{"category":"Lu","mappings":{"default":{"default":"sans-serif cursiva mayúscula J"}},"key":"1D611"},{"category":"Lu","mappings":{"default":{"default":"sans-serif cursiva mayúscula K"}},"key":"1D612"},{"category":"Lu","mappings":{"default":{"default":"sans-serif cursiva mayúscula L"}},"key":"1D613"},{"category":"Lu","mappings":{"default":{"default":"sans-serif cursiva mayúscula M"}},"key":"1D614"},{"category":"Lu","mappings":{"default":{"default":"sans-serif cursiva mayúscula N"}},"key":"1D615"},{"category":"Lu","mappings":{"default":{"default":"sans-serif cursiva mayúscula O"}},"key":"1D616"},{"category":"Lu","mappings":{"default":{"default":"sans-serif cursiva mayúscula P"}},"key":"1D617"},{"category":"Lu","mappings":{"default":{"default":"sans-serif cursiva mayúscula Q"}},"key":"1D618"},{"category":"Lu","mappings":{"default":{"default":"sans-serif cursiva mayúscula R"}},"key":"1D619"},{"category":"Lu","mappings":{"default":{"default":"sans-serif cursiva mayúscula S"}},"key":"1D61A"},{"category":"Lu","mappings":{"default":{"default":"sans-serif cursiva mayúscula T"}},"key":"1D61B"},{"category":"Lu","mappings":{"default":{"default":"sans-serif cursiva mayúscula U"}},"key":"1D61C"},{"category":"Lu","mappings":{"default":{"default":"sans-serif cursiva mayúscula V"}},"key":"1D61D"},{"category":"Lu","mappings":{"default":{"default":"sans-serif cursiva mayúscula W"}},"key":"1D61E"},{"category":"Lu","mappings":{"default":{"default":"sans-serif cursiva mayúscula X"}},"key":"1D61F"},{"category":"Lu","mappings":{"default":{"default":"sans-serif cursiva mayúscula Y"}},"key":"1D620"},{"category":"Lu","mappings":{"default":{"default":"sans-serif cursiva mayúscula Z"}},"key":"1D621"},{"category":"Ll","mappings":{"default":{"default":"sans-serif cursiva a"}},"key":"1D622"},{"category":"Ll","mappings":{"default":{"default":"sans-serif cursiva b"}},"key":"1D623"},{"category":"Ll","mappings":{"default":{"default":"sans-serif cursiva c"}},"key":"1D624"},{"category":"Ll","mappings":{"default":{"default":"sans-serif cursiva d"}},"key":"1D625"},{"category":"Ll","mappings":{"default":{"default":"sans-serif cursiva e"}},"key":"1D626"},{"category":"Ll","mappings":{"default":{"default":"sans-serif cursiva f"}},"key":"1D627"},{"category":"Ll","mappings":{"default":{"default":"sans-serif cursiva g"}},"key":"1D628"},{"category":"Ll","mappings":{"default":{"default":"sans-serif cursiva h"}},"key":"1D629"},{"category":"Ll","mappings":{"default":{"default":"sans-serif cursiva i"}},"key":"1D62A"},{"category":"Ll","mappings":{"default":{"default":"sans-serif cursiva j"}},"key":"1D62B"},{"category":"Ll","mappings":{"default":{"default":"sans-serif cursiva k"}},"key":"1D62C"},{"category":"Ll","mappings":{"default":{"default":"sans-serif cursiva l"}},"key":"1D62D"},{"category":"Ll","mappings":{"default":{"default":"sans-serif cursiva m"}},"key":"1D62E"},{"category":"Ll","mappings":{"default":{"default":"sans-serif cursiva n"}},"key":"1D62F"},{"category":"Ll","mappings":{"default":{"default":"sans-serif cursiva o"}},"key":"1D630"},{"category":"Ll","mappings":{"default":{"default":"sans-serif cursiva p"}},"key":"1D631"},{"category":"Ll","mappings":{"default":{"default":"sans-serif cursiva q"}},"key":"1D632"},{"category":"Ll","mappings":{"default":{"default":"sans-serif cursiva r"}},"key":"1D633"},{"category":"Ll","mappings":{"default":{"default":"sans-serif cursiva s"}},"key":"1D634"},{"category":"Ll","mappings":{"default":{"default":"sans-serif cursiva t"}},"key":"1D635"},{"category":"Ll","mappings":{"default":{"default":"sans-serif cursiva u"}},"key":"1D636"},{"category":"Ll","mappings":{"default":{"default":"sans-serif cursiva v"}},"key":"1D637"},{"category":"Ll","mappings":{"default":{"default":"sans-serif cursiva w"}},"key":"1D638"},{"category":"Ll","mappings":{"default":{"default":"sans-serif cursiva x"}},"key":"1D639"},{"category":"Ll","mappings":{"default":{"default":"sans-serif cursiva y"}},"key":"1D63A"},{"category":"Ll","mappings":{"default":{"default":"sans-serif cursiva z"}},"key":"1D63B"}]
