$wnd.rstudio.runAsyncCallback15("function I1p(){}\nfunction b1p(a){this.a=a}\nfunction G1p(a){this.a=a}\nfunction L1p(a){this.a=a}\nfunction N1p(a){this.a=a}\nfunction R2p(a){this.a=a}\nfunction Fyi(a){this.a=a}\nfunction _0p(a){Sci.call(this,a)}\nfunction I0p(a){U0p(a,new L1p(a))}\nfunction O0p(a){a.J.r4b();en((Zm(),Ym),new b1p(a))}\nfunction N0p(a){bxi(a.b,C0p.f5b(),C0p.f5b(),new N1p(a))}\nfunction P0p(a){Xet(a.n,new B1p(a,rYx,false),new D1p,uCy)}\nfunction M0p(a){Xet(a.n,new G1p(a),new I1p,C0p.$4b())}\nfunction R0p(a,b){qPh(a.d,new NCq(b,true,true),false)}\nfunction mxi(a,b){ywi();(YGe(b),b)&&T0p(a.a,ZXA,'')}\nfunction d1p(a,b){ilf();this.a=a;this.b=b;klf.call(this)}\nfunction K1p(a,b){R0p(a.a,'devtools::load_all(\"'+b+'\")')}\nfunction X2l(a,b){J7l(a,Kty,'devtools_load_all_path',new uL,b)}\nfunction U0p(a,b){a.c!=null?K1p(b,a.c):X2l(a.j,new d1p(a,b))}\nfunction bxi(a,b,c,d){Owi(a,b,c,ezi(pqo(a.i.b),'roxygen'),Bwi(a,'roxygen'),false,new Fyi(d))}\nfunction F0p(a,b){var c,d;mpi(a.q.g,null);d=b.outputs;for(c=0;c<d.length;c++)$_p(a.q,d[c]);b.errors.length>0&&Z_p(a.q,b.errors_base_dir,b.errors,false,0,true,b.type);b.running?f0e(a.a.Vj,true,false):lpi(a.q.g);wHg(a.q.g.c.c)}\nfunction N2p(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=b5p(a.a.b.a);rOp(a.a,a.a.a)}switch(a.c){case 1:F0p(a.a.a,a.b[0]);break;case 2:a.a.a.J.p4b();break;case 3:a.a.a.J.q4b();break;case 4:T0p(a.a.a,E7z,'');break;case 5:T0p(a.a.a,'build-binary-package','');break;case 6:T0p(a.a.a,'build-full','');break;case 7:T0p(a.a.a,'build-incremental','');break;case 8:T0p(a.a.a,'build-source-package','');break;case 9:T0p(a.a.a,'check-package','');break;case 10:T0p(a.a.a,'clean-all','');break;case 11:M0p(a.a.a);break;case 12:N0p(a.a.a);break;case 13:O0p(a.a.a);break;case 14:P0p(a.a.a);break;case 15:M8l(a.a.a.j,new _0p((D0p(),C0p).q5b()));break;case 16:T0p(a.a.a,'test-package','');break;case 19:a.a.a.J.s4b();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].ln()}}\nvar ZXA='roxygenize-package',$XA='Error Terminating Build',_XA='Unable to terminate build. Please try again.',aYA='Building package documentation',bYA='Terminating Build...';sFd(2288,1,jTx,Fyi);_.jw=function Gyi(a){mxi(this.a,a)};var bwb=dse(2288);sFd(7908,381,{},_0p);_.$m=function a1p(a){(YGe(a),a)||eci(3,(D0p(),C0p).b5b(),C0p.c5b()).HT()};var $cc=dse(7908);sFd(7909,1,oTx,b1p);_.ln=function c1p(){wHg(this.a.q.g.c.c)};var _cc=dse(7909);sFd(7910,53,{},d1p);_.oA=function e1p(a){this.a.c=a;K1p(this.b,this.a.c)};var adc=dse(7910);sFd(7901,1,oTx,G1p);_.ln=function H1p(){I0p(this.a)};var qdc=dse(7901);sFd(7902,1,oTx,I1p);_.ln=function J1p(){D0p()};var rdc=dse(7902);sFd(7900,1,jTx,L1p);_.jw=function M1p(a){K1p(this,a)};var sdc=dse(7900);sFd(7903,1,oTx,N1p);_.ln=function O1p(){T0p(this.a,ZXA,'')};var tdc=dse(7903);sFd(246,1,Kqy);_.jn=function Q2p(){N2p((new R2p(this)).a)};sFd(7206,1,oTx,R2p);_.ln=function S2p(){N2p(this.a)};var Qdc=dse(7206);sFd(5467,1,H7z);_.b5b=function c3p(){return $XA};_.c5b=function d3p(){return _XA};_.f5b=function g3p(){return aYA};_.q5b=function r3p(){return bYA};sFd(5466,1,H7z);_.b5b=function D3p(){return $XA};_.c5b=function E3p(){return _XA};_.f5b=function H3p(){return aYA};_.q5b=function S3p(){return bYA};sFd(5465,1,H7z);_.b5b=function c4p(){return 'Erreur de fin de construction'};_.c5b=function d4p(){return 'Impossible de terminer la construction. Veuillez r\\xE9essayer.'};_.f5b=function g4p(){return 'Documentation du paquet de construction'};_.q5b=function r4p(){return 'Terminer la construction...'};lDx(fm)(15);\n//# sourceURL=rstudio-15.js\n")
